@@ -41,8 +41,10 @@
 		     ("tgsl.scm" . "v-gsl")
 		     ("tlist.scm" . "v-list")
 		     ("tload.scm" . "v-load")
-		     ("cookbook.scm" . "v-cook")
+		     ("cb.scm" . "v-cb")
 		     ("tari.scm" . "v-ari")
+		     ("texit.scm" . "v-exit")
+		     ("tleft.scm" . "v-left")
 		     ))
 
 (define (last-callg)
@@ -76,20 +78,19 @@
 	 (system (format #f "./snd compare-calls.scm -e '(compare-calls \"~A~D\" \"~A~D\")'" outfile (- next 1) outfile next)))))
 
    (list (list "repl" "tpeak.scm")
-	 (list "repl" "tari.scm")
 	 (list "repl" "tref.scm")
 	 (list "repl" "tauto.scm")
-	 (list "repl" "tshoot.scm")
 	 (list "snd -noinit" "make-index.scm")
 	 (list "repl" "tmock.scm")
 	 (list "repl" "tvect.scm")
 	 (list "repl" "s7test.scm")
+	 (list "repl" "texit.scm")
 	 (list "repl" "lt.scm")
 	 (list "repl" "tform.scm")
-	 (list "repl" "tmac.scm")
 	 (list "repl" "tread.scm")
-	 (list "repl" "trclo.scm")
+	 (list "repl" "tmac.scm")
 	 (list "repl" "fbench.scm")
+	 (list "repl" "trclo.scm")
 	 (list "repl" "tmat.scm")
 	 (list "repl" "tcopy.scm")
 	 (list "repl" "dup.scm")
@@ -99,20 +100,23 @@
 	 (list "repl" "tload.scm")
 	 (list "repl" "teq.scm")
 	 (list "repl" "tio.scm")
-	 (list "repl" "concordance.scm")
 	 (list "repl" "tclo.scm")
 	 (list "repl" "tlet.scm")
 	 (list "repl" "tcase.scm")
 	 (list "repl" "tmap.scm")
 	 (list "repl" "tfft.scm")
+	 (list "repl" "tshoot.scm")
 	 (list "repl" "tnum.scm")
+	 (list "repl" "concordance.scm")
 	 (list "repl" "tgsl.scm")
 	 (list "repl" "trec.scm")
 	 (list "repl" "tmisc.scm")
 	 (list "repl" "tlist.scm")
+	 (reader-cond ((not (provided? 'gmp)) (list "repl" "tari.scm")))
+	 (list "repl" "tleft.scm")
 	 (list "repl" "tgc.scm")
 	 (list "repl" "thash.scm")
-	 (list "repl" "cookbook.scm")
+	 (list "repl" "cb.scm")
 	 (list "snd -noinit" "tgen.scm")    ; repl here + cload sndlib was slower
 	 (list "snd -noinit" "tall.scm")
 	 (list "snd -l" "snd-test.scm")
